% A part of the Matlab - Matisse interface
% Version 0.7 (July 2001)
%
% Database Modification.
%
% The database schema (so the meta-schema) cannot be modified with a default 
% connection. Only when the connection options are explicitly set to the 
% MT_DATA_DEFINITION mode, the schema and the meta-schema can be modified.
%
% Modifications can be performed during a transaction only. A check function 
% cannot execute any kind of modification. Furthermore, when a stream is opened,
% only the modifications that do not corrupt the stream are authorized. 
%
%   This part consists of the following functions, ordered by theme.
%   Functions marked with a '~' are not implemented yet.
%
%  Object Creation & Deletion 
%
%  When an object is created or deleted, a check is performed on the values 
%  that are stored. The values must respect the constraints that are specific 
%  to the database: it is not allowed to store a number higher than that 
%  specified, a type other than that specified, etc. There is no way to ignore 
%  this control.
%  The relavant entry-points, and each index attached to the class of the object 
%  are updated. 
%
%   MtCreateObject - creates one MATISSE object of a given class 
%   MtRemoveObject - deletes object and updates links, entry points, and indexes
%
%  Object Modification
%
%  If the value of the attribute is modified, the entry-point is updated if there 
%  is an entry-point function, and the entries for the object in any index attached to
%  the class are updated. 
%  If s successor is added to or deleted from a relationship, also the inverse 
%  relationship is modified.
%
% ~ MtAddNumSuccessors   
%   MtAddSuccessor        - adds a new successor to the relationship
% ~ MtAddSuccessors  
% ~ MtRemoveAllSuccessors  
% ~ MtRemoveNumSuccessors  
% ~ MtRemoveSuccessors  
% ~ MtRemoveValue  
%   MtSetListElements     - store a list as a subset of an existing list attribute 
%   MtSetValue            - updates an attribute with a new value
%
%  Object Validation and Check Functions
%
%  Objects that are modified during a transaction are checked at the end of 
%  the transaction only (i.e. when MtCommitTransaction is called). If you want
%  to check the objects during the transaction, you must use one of the
%  dedicated check functions. These functions call the check functions attached 
%  to the classes and to the properties.
%
% ~ MtCheckAttribute 
% ~ MtCheckInstance 
% ~ MtCheckProperty 
% ~ MtCheckRelationship 
%
%
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@wins.uva.nl>
