% MtCommitTransaction ends a transaction and commits any modification
%
%   status = MtCommitTransaction;
%   [status, versionName] = MtCommitTransaction (prefix);
%
%   This function puts an end to a transaction through the commit of any modification. 
%   Moreover, it offers the possibility to save an instant view of the database, 
%   for future accesses in version mode (refer to the function MtStartVersionAccess).
%
%   Objects that are modified or created during a transaction are checked at the end 
%   of the transaction only (i.e. when MtCommitTransaction is called). If you want to 
%   check the objects during the transaction, you must use a specific function (see
%   MatisseModification). This check is made through the check functions associated 
%   with the classes and the properties.
%
%   If one of the check functions fails, the variable mtInvalidObject is set to 
%   the object that has caused the error.
%
%   MATISSE_WAITTIME occurs only if there is a read lock when the objects are being 
%   checked. If write locks cannot be acquired while the objects are being written, 
%   the MATISSE_WRITEWAITTIME error occurs. Even though the transaction is neither 
%   committed nor aborted, no more modifications are allowed. Until the end of the 
%   transaction (that is when either MtCommitTransaction or MtAbortTransaction 
%   returns MATISSE_SUCCESS), all the modification functions will return 
%   MATISSE_INVALOP.
%
%   OUTPUT [1 or 2]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      versionName: string (optional)
%          If prefix is given, this argument receives the database version 
%          identifier that is saved. It is made up of the 20 first characters 
%          (maximum) of prefix, followed by a hexadecimal number. This string 
%          will reference the version in MtStartVersionAccess. 
%
%   INPUT [0 or 1]
%
%      prefix: string (optional)
%          If you want to maintain a version of the database (for a future access 
%          in version mode), this argument must point to a string of 20 characters 
%          as a maximum. This string will ease the creation of a database version 
%          identifier at the end of the transaction.
%
%   See also: 
%      MatisseAccess
%      MtAbortTransaction
%      MtStartTransaction

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001   

