% MtGetIndexInfo returns information on the specified index. 
%
%   [status, ...] = ...
%                 MtGetIndexInfo (index, ...); 
%   [status, nbOfEntries, indexInfo, nbOfClasses, classes] = ...
%                 MtGetIndexInfo (index, 1, 1, 1, 1);
%
%   An index can have up to 4 criteria, which all 4 can be of a different type.
%   With this function you get an overview of the criteria defined for the 
%   given index.
%
%   [status, nbOfEntries, indexInfo, nbOfClasses, classes] = ...
%                 MtGetIndexInfo (index, 1, 1, 1, 1);
%
%
%   OUTPUT [1,2,3,4 or 5]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      nbOfEntries: number (optional)
%          The number of entries in the index
%
%      indexInfo: struct-array (optional)
%          The index information. This struct contains the following fields:    
%  struct {
%    MtOid	attributeKey;
%    MtType	type;
%    MtS32	size;
%    MtOrdering	order;
%  };
%
%      nbOfClasses: number (optional)
%          The number of classes linked to the index.
%
%      typesize: number-array (optional)
%          A list of keys to the classes in the index. 
%
%   INPUT [5]
%
%      index: number or string
%           An key to an index or an index name.
%
%      nbOfEntries: number
%          a flag to indicate if the nbOfEntries has to be retrieved. 
%
%      indexInfo: number
%          a flag to indicate if the indexInfo has to be retrieved 
%
%      nbOfClasses: number
%          a flag to indicate if the nbOfClasses has to be retrieved. 
%
%      classes: number
%          a flag to indicate if the classes has to be retrieved 
%
%   See also:
%
%      MtGetIndex
%      MtOpenIndexEntriesStream

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001   

