% MtGetPredecessors returns a list of all the objects that are predecessors.
%
%   [status, numPredecessors] = ...
%      MtGetPredecessors (numPredecessors, 0, object, relationship);
%   [status, numPredecessors, predecessors] = ...
%      MtGetPredecessors (numPredecessors, 1, object, relationship);
%
%   If the relationship is a relationship defined for object, or an inverse 
%   relationship of a relationship of which object can be a predecessors, this 
%   function returns an array that contains all the objects that are predecessors 
%   through the specified relationship.
%
%   OUTPUT [2 or 3]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      numPredecessors: number
%          As output, it indicates the total number of predecessors of the object  
%          through the relationship. 
%
%      predecessors: 1xnumPredecessors array of numbers (optional
%          this array will contain the predecessors of object through the relationship. 
%          When the second input argument is set to NULL, the function does not 
%          return this argument. 
%
%   INPUT [4]
%
%      numPredecessors: number
%          In input, specifies the maximum size of the array wanted by the user. 
%
%      predecessors: number
%          a flag to indicate if the list of predecessors has to be retrieved. 
%          Otherwise the function simply returns the number of predecessors of 
%          the object through the relationship. 
%
%     object: number
%           The key to an object.
%
%     relationship: number or string
%           The key or name of a relationship.
%
% See also:
%   MatisseReading 

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001   

