% MtNextObject returns the next object in a stream.
%
%   [status, object] = MtNextObject (stream);
%
%   Depending on the stream type, the identifier is either that of a class instance
%   (see MtOpenInstancesStream), that of an object indexed by an entry point 
%   (see MtOpenEntryPointStream) or by an index (see MtOpenIndexEntriesStream), or
%   that of the object's successor (see MtOpenSuccessorsStream) or predecessor 
%   (see MtOpenIRelStream). Once all the objects have been accessed, the function 
%   returns MATISSE_ENDOFSTREAM, and object is set to 0.
%
%   This function can be called inside a transaction or during a version access.
%
%
%   OUTPUT [2]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      object: number
%          The key to the subsequent object in the stream, or NULL if there is no 
%          subsequent element. 
%
%   INPUT [1]
%
%      stream: number
%          A class stream, an entry-point stream, a relationship stream, 
%          a selection stream or an inverse relationship stream.
%
%   See also: 
%      MtNextIndexEntry
%      MtNextObjects
%      MtOpenInstancesStream
%      MtOpenEntryPointStream
%      MtOpenIndexEntriesStream
%      MtOpenPredecessorsStream
%      MtOpenSuccessorsStream 

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001  
