% MtSQLGetRowListElements retrieve large column values from a stream.
%
%   [status, bufList, numElts] = ...
%      MtSQLGetRowListElements (stream, colNum, colType, numElts, offset);
%
%   This function implements the streaming API for large attributes of type 
%   MT_U8_LIST. This API allows to read a large attribute by chunk directly from 
%   the server, without internal caching in the MATISSE Client.
%
%   MATISSE internally manages an offset for each list value. This offset is set 
%   to firstEltOffset + numElts after every call to the MtSQLGetRowListElements 
%   function. It can be used for further access by specifying MT_CURRENT_OFFSET as 
%   value for the firstEltOffset argument. There is no default offset so 
%   MT_CURRENT_OFFSET cannot be specified at the first call.
%
%   The offset management remains coherent only within the same transaction or 
%   version access.
%
%   OUTPUT [3]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      bufList: number
%          The key to the subset retrieved by the function. 
%
%      numElts: number
%          As output it indicates the exact number of elements of the subset. 
%
%   INPUT [5]
%
%      stream: number
%          The key to a stream opened on the SQL result selection. 
%
%      colNum: number
%          Column number, starting at 1.
%
%      type: number or string
%          The expected type of the list value. There is only one possible type:
%          'MT_U8_LIST'.
%
%      numElts: number
%          As input, this parameter indicates the maximum number of elements to 
%          be read for the subset. 
%
%      offset: number or string
%          The offset (or position) of the first element of the subset to be retrieved. 
%          The first element in the list value has the offset 0.
%
%          Two specific values are allowed:
%          - 'MT_BEGIN_OFFSET',
%          - 'MT_CURRENT_OFFSET',
%         The last one means "the next element immediately after the last accessed 
%         element". 
%
% See also:
%   MatisseSQL 

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001  
