% MtSQLNextRow fetch the next row from the selection.
%
%   status = MtSQLNextRow (stream);
%
%   Fetch the next row from a SQL selection produced by the successful execution 
%   of a SQL statement. The values for the columns of the current row can then be 
%   retrieved with the functions MtSQLGetRowValue and MtSQLGetRowListElements.
%
%   MtSQLNextRow should be used instead of MtNextObject in order to retrieve the 
%   colum values for a SQL result set. In particular, this interface allows to 
%   retrieve computed values like COUNT, AVG, SUM.
%
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%
%   INPUT [1]
%
%      stream: number
%          A class stream, an entry-point stream, a relationship stream, 
%          a selection stream or an inverse relationship stream.
%
%   See also: 
%      MatisseSQL
%
%   Example:
%   %  The following example shows how to execute a SELECT statement and  
%   %  retrieve the values for the 1st column with the projection API.
%
%   colnum = 1;
%   [status, sqlResult] = ...
%          MtSQLExec ('CONNECT TO "VideoStore"');
%   [status, sqlResult] = MtSQLExec ('SELECT Title FROM Movie');
%
%   selection = sqlResult.selection;
%   
%   [status, stream] = MtSQLOpenSelectionStream (selection);
%   status = MtSQLNextRow(stream);
%
%   while strcmp (status, 'MATISSE_SUCCESS');
%
%        [status, type, title, size] = ...
%               MtSQLGetRowValue(stream, colnum, 'MT_STRING', 1, 1024);
%        title
%        status = MtSQLNextRow(stream);
%   end
%   
%   status = MtCloseStream (stream);
%   status = MtSQLFreeSelection (selection);
%   [status, sqlResult] = MtSQLExec ('ROLLBACK');
%   [status, sqlResult] = MtSQLExec ('DISCONNECT CURRENT');

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.1.29215a (R11.1) - Matisse 5.0b2
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    July 2001

